diff --git a/Reconstruction/RecExample/RecExConfig/python/RecFlags.py b/Reconstruction/RecExample/RecExConfig/python/RecFlags.py
index 3857794353105e2da98c694dfb4972cd6d5fdf82..3a9c643fbf9ee7c70b6a3e4f4db927bbf2d876e9 100755
--- a/Reconstruction/RecExample/RecExConfig/python/RecFlags.py
+++ b/Reconstruction/RecExample/RecExConfig/python/RecFlags.py
@@ -472,7 +472,7 @@ class doWriteDPD(JobProperty):
     """
     statusOn=True
     allowedTypes=['bool']
-    StoredValue=True
+    StoredValue=False
 
 #
 class doWriteBS(JobProperty):
diff --git a/Reconstruction/RecJobTransforms/share/skeleton.RAWtoALL_tf.py b/Reconstruction/RecJobTransforms/share/skeleton.RAWtoALL_tf.py
index 8808aa7785db5c72024e2e0a340cb3a7a1d447d5..a33f1f71daec30b8353fa25bd6944fcafaedc47c 100644
--- a/Reconstruction/RecJobTransforms/share/skeleton.RAWtoALL_tf.py
+++ b/Reconstruction/RecJobTransforms/share/skeleton.RAWtoALL_tf.py
@@ -97,7 +97,14 @@ if hasattr(runArgs,"outputNTUP_MUONCALIBFile"):
 if hasattr(runArgs, 'outputTXT_JIVEXMLTGZFile'):
     jp.Rec.doJiveXML.set_Value_and_Lock(True)
 
-# DESD and DRAW
+# DESD, DAOD and DRAW
+DRAWOutputs = [ prop for prop in dir(runArgs) if prop.startswith('outputDRAW') and prop.endswith('File')]
+DAODOutputs = [ prop for prop in dir(runArgs) if prop.startswith('outputDAOD') and prop.endswith('File')]
+DESDOutputs = [ prop for prop in dir(runArgs) if prop.startswith('outputDESD') and prop.endswith('File')]
+
+if len(DESDOutputs) > 0 or len(DAODOutputs) > 0:
+    rec.doWriteDPD.set_Value_and_Lock(True)
+
 listOfFlags=[]
 try:
     from PrimaryDPDMaker.PrimaryDPDFlags import primDPD
@@ -108,9 +115,6 @@ except ImportError:
 from RecJobTransforms.DPDUtils import SetupOutputDPDs
 rec.DPDMakerScripts.append(SetupOutputDPDs(runArgs,listOfFlags))
 
-DRAWOutputs = [ prop for prop in dir(runArgs) if prop.startswith('outputDRAW') and prop.endswith('File')]
-
-
 # Need to handle this properly in RecExCommon top options
 rec.OutputFileNameForRecoStep="RAWtoALL"